fdt: Use the correct return types for fdtdec_decode_region()

Use the correct FDT data types for this function. Also add more debugging.

Acked-by: Anatolij Gustschin <agust@denx.de>
Signed-off-by: Simon Glass <sjg@chromium.org>
Reviewed-by: Tom Rini <trini@ti.com>
diff --git a/include/fdtdec.h b/include/fdtdec.h
index 4ae77be..099930e 100644
--- a/include/fdtdec.h
+++ b/include/fdtdec.h
@@ -595,12 +595,12 @@
  * @param blob		FDT blob
  * @param node		node to examine
  * @param prop_name	name of property to find
  * @param ptrp		returns pointer to region, or NULL if no address
  * @param size		returns size of region
  * @return 0 if ok, -1 on error (propery not found)
  */
-int fdtdec_decode_region(const void *blob, int node,
-		const char *prop_name, void **ptrp, size_t *size);
+int fdtdec_decode_region(const void *blob, int node, const char *prop_name,
+			 fdt_addr_t *basep, fdt_size_t *sizep);
 
 /* A flash map entry, containing an offset and length */
 struct fmap_entry {
@@ -595,12 +595,12 @@
  * @param node		node to examine
  * @param prop_name	name of property to find
- * @param ptrp		returns pointer to region, or NULL if no address
- * @param size		returns size of region
- * @return 0 if ok, -1 on error (propery not found)
+ * @param basep		Returns base address of region
+ * @param size		Returns size of region
+ * @return 0 if ok, -1 on error (property not found)
  */